==> topia-persistence-3.0-sources.jar: org/nuiton/topia/persistence/TopiaDaoSupplier.java <==
package org.nuiton.topia.persistence;

/*
 * #%L
 * ToPIA :: Persistence
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2004 - 2014 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * Contract that provides any Dao instance from a given entity class.
 *
 * @author bleny
 * @since 3.0
 */
public interface TopiaDaoSupplier {

    /**
     * Get Dao for specified class. If the specialized Dao exists then it is returned otherwise a TopiaException will
     * be thrown.
     *
     * @param entityClass type of entity
     * @return the expected dao
     */
    <E extends TopiaEntity> TopiaDao<E> getDao(Class<E> entityClass);

    /**
     * Get Dao for specified class. If the specialized Dao exists then it is returned otherwise a TopiaException will be
     * thrown.
     *
     * @param entityClass type of entity
     * @param daoClass    the concrete dao class to use
     * @return the expected dao
     */
    <E extends TopiaEntity, D extends TopiaDao<E>> D getDao(Class<E> entityClass, Class<D> daoClass);

}

==> topia-persistence-3.2.2-20170414.095053-2-sources.jar: org/nuiton/topia/persistence/TopiaDaoSupplier.java <==
package org.nuiton.topia.persistence;

/*
 * #%L
 * ToPIA :: Persistence
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2004 - 2014 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * Contract that provides any Dao instance from a given entity class.
 *
 * @author bleny
 * @since 3.0
 */
public interface TopiaDaoSupplier {

    /**
     * Get Dao for specified class. If the specialized Dao exists then it is returned otherwise a TopiaException will
     * be thrown.
     *
     * @param <E>         type of entity
     * @param entityClass type of entity
     * @return the expected dao
     */
    <E extends TopiaEntity> TopiaDao<E> getDao(Class<E> entityClass);

    /**
     * Get Dao for specified class. If the specialized Dao exists then it is returned otherwise a TopiaException will be
     * thrown.
     *
     * @param <E>         type of entity
     * @param <D>         type of dao
     * @param entityClass type of entity
     * @param daoClass    the concrete dao class to use
     * @return the expected dao
     */
    <E extends TopiaEntity, D extends TopiaDao<E>> D getDao(Class<E> entityClass, Class<D> daoClass);

}
